"""
$URL: svn+ssh://svn.mems-exchange.org/repos/trunk/qp/setup.py $
$Id: setup.py 27609 2005-10-20 01:14:38Z dbinger $
"""

#import distutils.debug
#distutils.debug.DEBUG
import sys
from os import curdir, symlink
from os.path import join, exists
from distutils.core import setup
from distutils.command.build_py import build_py
from distutils.extension import Extension
from shutil import copytree
try:
    from qpy.setup import qpy_build_py
except ImportError:
    print "Please install Qpy first."
    raise SystemExit

Passfd = Extension(name="qp.hub.passfd", sources=['hub/passfd.c'])

if __name__ == '__main__':
    if len(sys.argv) == 3 and sys.argv[1] == 'install_sites_link':
        sites_directory = sys.argv[2]
        if not exists(sites_directory):
            print sites_directory, 'does not exist.'
        if not exists(join(sites_directory, '__init__.py')):
            print sites_directory, 'needs an __init__.py.'
        import qp
        symlink(sites_directory, join(qp.__path__[0], 'sites'))
    elif len(sys.argv) == 3 and sys.argv[1] == 'install_demo_sites':
        sites_directory = sys.argv[2]
        if exists(sites_directory):
            print sites_directory, 'already exists.'
        copytree('demo', sites_directory)
        f = open(join(sites_directory, "__init__.py"), "w")
        f.close()
    else:
        setup(name="qp",
              version="1.0",
              author="CNRI",
              author_email="webmaster@mems-exchange.org",
              url="http://www.mems-exchange.org/software/qp/",
              package_dir=dict(qp=curdir),
              scripts=['bin/qp', 'bin/qpcensus.py'],
              license="See LICENSE.txt",
              packages=['qp',
                        'qp.http',
                        'qp.hub',
                        'qp.pub',
                        'qp.fill',
                        'qp.lib',
                        'qp.mail',
                        ],
              ext_modules=[Passfd],
              description="A web-application framework.",
              cmdclass= {'build_py': qpy_build_py},
              long_description=(
            "QP is a package for defining and running multiple web "
            "applications based on Durus for persistence, standard persistent "
            "Session and User classes, easy interactive database sessions, "
            "qpy for assembling html, and Quixote2-style forms and path "
            "traversal.  ")
              )



"""
$URL: svn+ssh://svn.mems-exchange.org/repos/trunk/qp/pub/common.py $
$Id: common.py 27227 2005-08-18 22:20:59Z dbinger $

Code for maintaining the global Publisher, and convenience functions
for operations that go through the publisher.
"""

_publisher = None

def set_publisher(value):
    global _publisher
    assert _publisher is None
    _publisher = value

def clear_publisher():
    # Used in test scripts only.
    global _publisher
    _publisher = None

def get_publisher():
    return _publisher

# All of the remaining functions here work through get_publisher().

def get_hit():
    return get_publisher().get_hit()

def get_request():
    return get_hit().get_request()

def get_response():
    return get_hit().get_response()

def get_session():
    return get_hit().get_session()

def get_user():
    return get_session().get_effective_user()

def get_site():
    return get_publisher().get_site()

def get_path(n=0):
    return get_request().get_path(n=n)

def redirect(location, permanent=False):
    get_publisher().redirect(location, permanent=permanent)

def not_found(body=None):
    get_publisher().not_found(body=body)

def header(title, *args, **kwargs):
    return get_publisher().header(title, *args, **kwargs)

def footer(**kwargs):
    return get_publisher().footer(**kwargs)

def page(title, *content, **kwargs):
    return get_publisher().page(title, *content, **kwargs)

def respond(title, *content, **kwargs):
    return get_publisher().respond(title, *content, **kwargs)

def ensure_signed_in(**kwargs):
    return get_publisher().ensure_signed_in(**kwargs)



